@@ -13,6 +13,7 @@ is embedded into the end program.
 
 import contextlib
 import datetime
+import decimal
 import functools
 import json
 import logging
@@ -408,6 +409,8 @@ class Cursor:
             for column, val in record.items():
                 if isinstance(val, dict):
                     record[column] = JSONEncoder().encode(val)
+                elif isinstance(val, decimal.Decimal):
+                    record[column] = float(val)
             columns, vals = zip(*record.items())
             values.append(vals)
         sql = "{} INTO {}({})".format(
